
            """
            if not self.sentAudio:
                self.sentAudio = True
                print("Read")
                with open("sample.mp2", mode="rb") as file:  # b is important -> binary
                    fileContent = file.read()
                data = fileContent
                headers = {}
                headers[b"Content-Type"] = str("audio/mp2t").encode()
                headers[b"X-Session-Id"] = str(session).encode()
                headers[b"Content-Length"] = str(len(data)).encode()

                await self._send_http_request(b"--" + self.client_boundary, headers)
                chunk_size = 4096
                for i in range(0, len(data), chunk_size):
                    print(data[i : i + chunk_size])
                    self._writer.write(data[i : i + chunk_size])
                    await self._writer.drain()

                print("sending payload")
            """



import hashlib
import os

from typing import Mapping, Tuple, Optional


def md5digest(to_hash: bytes) -> bytes:
    return hashlib.md5(to_hash).digest().hex().upper().encode()


def generate_nonce(length: int) -> bytes:
    return os.urandom(length).hex().encode()


def parse_http_headers(data: bytes) -> Mapping[str, str]:
    return {
        i[0].strip(): i[1].strip()
        for i in (j.split(":", 1) for j in data.decode().strip().split("\r\n"))
    }


def parse_http_response(res_line: bytes) -> Tuple[bytes, int, Optional[bytes]]:
    http_ver, status_code_and_status = res_line.split(b" ", 1)
    if b" " in status_code_and_status:
        status_code, status = status_code_and_status.split(b" ", 1)
    else:
        status_code = status_code_and_status
        status = None
    return http_ver, int(status_code.decode()), status
